@@ -53,6 +53,8 @@ class NNResNetRegressor(L.LightningModule):
         _L_in: int,
         _L_out: int,
         _torchmetric: str,
+        *args,
+        **kwargs,
     ):
         super().__init__()
         self._L_in = _L_in
